# Elyzo CLI & SDK

This is the official CLI and SDK for interacting with the Elyzo platform.

This tool allows you to:

* Test agent runs against the Elyzo hosted runtime.

* Deploy agents to the platform.

* Create and manage agent configurations.

## Installation

pip install elyzo


## Usage

Once installed, you can use the `elyzo` command in your terminal.

elyzo --help